kicad_bom
=========

KiCad Python module for generating bill of materials in multiple
formats.

Authors:

    Peter Polidoro <peterpolidoro@gmail.com>
    Jean-Pierre Charras jean-pierre.charras[at]gipsa-lab-dot-inpg-dot-fr

Package Maintainers:

    Peter Polidoro <peterpolidoro@gmail.com>

License:

    GPL
